==> wifiinfo_0.9.20091009-1.tar.gz: wifiinfo-0.9.20091009/src/ConfigDialog.cpp <==
/*
  This file is part of "WeightJinni" - A program to control your weight.
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include "ConfigDialog.h"

#include <Lum/Base/L10N.h>

#include <Lum/Label.h>
#include <Lum/Panel.h>
#include <Lum/Slider.h>

ConfigDialog::ConfigDialog(Lum::Model::Int* refreshTime)
: refreshTime(refreshTime),
  okAction(new Lum::Model::Action())
{
  refreshTime->Push();

  Observe(okAction);

  SetExitAction(GetClosedAction());
}

ConfigDialog::~ConfigDialog()
{
  refreshTime->Pop();
}

Lum::Object* ConfigDialog::GetContent()
{
  Lum::Label  *label;
  Lum::Panel  *panel;
  Lum::Slider *slider;

  panel=Lum::VPanel::Create(true,false);

  slider=new Lum::HSlider();
  slider->SetFlex(true,false);
  slider->SetScale(true);
  slider->SetModel(refreshTime);

  label=Lum::Label::Create(true,false);
  label->AddLabel(L"Refresh time:",slider);

  panel->Add(label);

  return panel;
}

void ConfigDialog::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
{
  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
}

void ConfigDialog::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
{
 if (model==okAction && okAction->IsFinished()) {
    refreshTime->Save();

    Exit();
  }

  Dialog::Resync(model,msg);
}

==> wifiinfo_0.10.20100104-2.tar.gz: wifiinfo-0.10.20100104/src/ConfigDialog.cpp <==
/*
  WifiInfo - Show current Wifi status
  Copyright (C) 2009  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "ConfigDialog.h"

#include <Lum/Base/L10N.h>

#include <Lum/Label.h>
#include <Lum/Panel.h>
#include <Lum/Slider.h>

ConfigDialog::ConfigDialog(Lum::Model::Int* refreshTime)
: refreshTime(refreshTime),
  okAction(new Lum::Model::Action())
{
  refreshTime->Push();

  Observe(okAction);

  SetExitAction(GetClosedAction());
}

ConfigDialog::~ConfigDialog()
{
  refreshTime->Pop();
}

Lum::Object* ConfigDialog::GetContent()
{
  Lum::Label  *label;
  Lum::Panel  *panel;
  Lum::Slider *slider;

  panel=Lum::VPanel::Create(true,false);

  slider=new Lum::HSlider();
  slider->SetFlex(true,false);
  slider->SetScale(true);
  slider->SetModel(refreshTime);

  label=Lum::Label::Create(true,false);
  label->AddLabel(L"Refresh time:",slider);

  panel->Add(label);

  return panel;
}

void ConfigDialog::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
{
  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
}

void ConfigDialog::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
{
 if (model==okAction && okAction->IsFinished()) {
    refreshTime->Save();

    Exit();
  }

  Dialog::Resync(model,msg);
}
